!{\src2tex{textfont=tt}}
!!****f* ABINIT/calc_dij0
!! NAME
!! calc_dij0
!!
!! FUNCTION
!! Compute initial values of Dij = Dij0
!!
!! COPYRIGHT
!! Copyright (C) 1998-2005 ABINIT group (FJ, MT)
!! This file is distributed under the terms of the 
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~ABINIT/Infos/contributors .
!! 
!! INPUTS
!!  pawarray
!!    %gnorm(l_size)= Normalisation of shape function for each l
!!    %kij(lmn2_size)= Kinetic overlap operator
!!    %shapefunc(sph_meshsz)= Normalized shape function
!!    %vhnzcij(lmn2_size)= (i,j) channel of the Hartree term inside
!!                         the spheres for the density nZc
!!    %vhtnzcij(lmn2_size)= matrix element of the Hartree potential of
!!                          the ps-density of the nucleus+core electrons
!!  pawdata
!!    %indlmn(6,lmn_size)= Gives l,m,n,lm,ln,s for i=lmn
!!    %rad(max_meshsz)= Coordinates of the radial grid
!!  pawps
!!    %phi(sph_meshsz,basis_size)= PAW atomic wavefunctions on the radial grid
!!    %tphi(sph_meshsz,basis_size)= PAW atomic pseudo-wavefunctions on the radial grid
!!    %vhtnzc(core_meshsz)= Hartree potential of the ps-density
!!                           of the nucleus + core electrons
!!  pshead
!!    %lmn_size= Number of elements for the paw basis
!!    %rad_step= Step corresponding to radial mesh
!!    %sph_meshsz= Dimension of radial mesh for PAW spheres
!!
!! OUTPUT
!!  pawps
!!    %dij0(lmn2_size)= Part of the Dij term calculated in the psp part
!!
!! PARENTS
!!      atompaw2abinit
!!
!! CHILDREN
!!      csimp
!!
!! SOURCE

 subroutine calc_dij0(pawarray,pawdata,pawps,pshead)

 use defs_basis
 use defs_pawps
 
 implicit none
 
!Arguments ---------------------------------------------
 type(pawarray_type) :: pawarray
 type(pawdata_type)  :: pawdata
 type(pawps_type)    :: pawps
 type(pshead_type)   :: pshead

!Local variables ---------------------------------------
 integer :: il,ilm,iln,ilmn,j0lmn,jl,jlm,jln,jlmn,klmn
 real(dp) :: intvh
 real(dp),allocatable :: ff(:),qij0(:)

! *************************************************************************

 allocate(ff(pshead%sph_meshsz))

!Computation of qij0
!-------------------
 allocate(qij0(pshead%lmn2_size));qij0=zero
 do jlmn=1,pshead%lmn_size
  jl =pawdata%indlmn(1,jlmn)
  jln=pawdata%indlmn(5,jlmn)
  j0lmn=jlmn*(jlmn-1)/2
  do ilmn=1,jlmn
   il= pawdata%indlmn(1,ilmn)
   iln=pawdata%indlmn(5,ilmn)
   klmn=j0lmn+ilmn
   if (il==jl) then
    ff(1:pshead%sph_meshsz)=(pawps%phi (1:pshead%sph_meshsz,iln)*pawps%phi (1:pshead%sph_meshsz,jln)&
&                           -pawps%tphi(1:pshead%sph_meshsz,iln)*pawps%tphi(1:pshead%sph_meshsz,jln))
    call csimp(ff,pshead%sph_meshsz,pshead%rad_step,qij0(klmn))
   endif
  enddo
 enddo

!Computation of int[vh(tnzc)*Qijhat(r)dr]
!----------------------------------------
 ff(1:pshead%sph_meshsz)=pawps%vhtnzc(1:pshead%sph_meshsz) &
&                       *pawarray%gnorm(1)*pawarray%shapefunc(1:pshead%sph_meshsz) &
&                       *pawdata%rad(1:pshead%sph_meshsz)**2
 call csimp(ff,pshead%sph_meshsz,pshead%rad_step,intvh)
 deallocate(ff)

!Computation of dij0
!-------------------
 pawps%dij0=zero
 do jlmn=1,pshead%lmn_size
  j0lmn=jlmn*(jlmn-1)/2;jlm=pawdata%indlmn(4,jlmn)
  do ilmn=1,jlmn
   klmn=j0lmn+ilmn;ilm=pawdata%indlmn(4,ilmn)
   if (jlm==ilm) pawps%dij0(klmn)=-intvh*qij0(klmn)
  enddo
 enddo
 pawps%dij0(:)=pawps%dij0(:)+pawarray%kij(:)+pawarray%vhnzcij(:)-pawarray%vhtnzcij(:)
 deallocate(qij0)

 end subroutine
!!***
