!{\src2tex{textfont=tt}}
!!****f* ABINIT/calc_rhoij0
!! NAME
!! calc_rhoij0
!! 
!! FUNCTION
!! Compute initial values (atomic initialization) of rhoij0
!!
!! COPYRIGHT
!! Copyright (C) 1998-2005 ABINIT group (FJ, MT)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~ABINIT/Infos/contributors .
!!
!! INPUTS
!!  pawdata
!!    %indlmn(6,lmn_size)= Gives l,m,n,lm,ln,s for i=lmn
!!  pshead
!!    %atomic_charge= Total atomic charge
!!    %basis_size= Number of elements for the paw nl basis
!!    %core_charge= Core charge
!!    %lmn_size= Number of elements for the paw basis
!!    %orbitals(basis_size)= Quantum number l for each basis function
!!
!! OUTPUT
!!  pawps
!!    %rhoij0= Atomic initialization of rhoij
!!
!! PARENTS
!!      atompaw2abinit
!!
!! CHILDREN
!!
!! SOURCE

 subroutine calc_rhoij0(pawdata,pawps,pshead)

 use defs_basis
 use defs_pawps

 implicit none

!Arguments ---------------------------------------------
 type(pawdata_type)  :: pawdata
 type(pawps_type)    :: pawps
 type(pshead_type)   :: pshead

!Local variables ---------------------------------------
 integer :: ib,ib0,ii,ilmn,ilmn0,in,ll2
 real(dp) :: sumocc,zval
 real(dp), allocatable :: occ(:)

! *************************************************************************

 pawps%rhoij0=zero

!Deduce occupations      ! simplified by NAWH 1/26/06  (needs checking)
! allocate(occ(pshead%basis_size));occ=zero
! zval=pshead%atomic_charge-pshead%core_charge
! sumocc=zero
! do ii=1,4;ib0=-1
!  do ilmn=1,pshead%lmn_size
!   ib=pawdata%indlmn(5,ilmn)
!   in=pawdata%indlmn(3,ilmn)
!   if (ib/=ib0) then
!    ib0=ib
!    if (in==ii) then
!     ll2=4*pawdata%indlmn(1,ilmn)+2
!     occ(ib)=occ(ib)+min(zval-sumocc,dble(ll2))
!     sumocc=sumocc+min(zval-sumocc,dble(ll2))
!    endif
!   end if
!   if (sumocc>=zval-tol8) exit
!  enddo
!  if (sumocc>=zval-tol8) exit
! enddo

!Filter integer occs
! do ib=1,pshead%basis_size
!  if (abs(occ(ib)-nint(occ(ib)))<tol8) occ(ib)=nint(occ(ib))
! end do

!Store Rhoij0
 ilmn0=0
 do ib=1,pshead%basis_size
  ll2=2*pshead%orbitals(ib)+1
  do ilmn=ilmn0+1,ilmn0+ll2
   pawps%rhoij0(ilmn*(ilmn+1)/2)=pshead%occ(ib)/dble(ll2)
  enddo
  ilmn0=ilmn0+ll2
 enddo

! deallocate(occ)

 end subroutine
!!***

