!{\src2tex{textfont=tt}}
!!****f* ABINIT/initpawps
!! NAME
!! initpawps
!! 
!! FUNCTION
!! Initialize several quantities
!!
!! COPYRIGHT
!! Copyright (C) 1998-2005 ABINIT group (FJ, MT)
!! This file is distributed under the terms of the 
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~ABINIT/Infos/contributors .
!! 
!! INPUTS 
!!  pshead
!!    %basis_size= Number of elements for the paw nl basis
!!    %core_meshsz= Dimension of radial mesh for core density
!!    %lmn_size= Number of elements for the paw basis
!!    %orbitals(basis_size)= Quantum number l for each basis function
!!    %sph_meshsz= Dimension of radial mesh for PAW spheres
!!
!! OUTPUT
!!  pawdata
!!    %indlmn(6,lmn_size)= Gives l,m,n,lm,ln,s for i=lmn
!!    %max_meshsz= Maximal size for radial meshes
!!  pshead
!!    %creatorid= ID of psp generator (here pspfmt=1 !)
!!    %l_size= Max. value of l+1 leading to a non zero Gaunt coeffs
!!    %lmax= Maximum value of l
!!    %lmn2_size= lmn_size*(lmn_size+1)/2
!!    %mesh_type=  Flag defining ther radial grid type
!!    %pspcod= Psp code number for Abinit (here PAW->pspcod=7 !)
!!    %pspxc_abinit= Abinit s code number for the exchange-correlation
!!  version= version number for AtomPAW2Abinit
!!
!! PARENTS
!!      atompaw2abinit
!!
!! SOURCE

 subroutine initpawps(pawdata,pshead,version)

 use defs_basis
 use defs_pawps

 implicit none

!Arguments ---------------------------------------------
 type(pawdata_type) :: pawdata
 type(pshead_type) :: pshead
 character*5 :: version

!Local variables ---------------------------------------
 real(dp),parameter :: rmax_vloc=10.d0 !We decide to cut at r=10 u.a because of numeric noise...
 integer :: ii1,ii2,ii3,ib,il,ilm,ilmn,iln,nproj

!--------------------------------------------------------

!Format codes for Abinit pseudopotential
 read(unit=version(1:1),fmt='(i1)') ii1
 read(unit=version(3:3),fmt='(i1)') ii2
 read(unit=version(5:5),fmt='(i1)') ii3
 pshead%creatorid=1000+100*ii1+10*ii2+ii3
 pshead%pspcod=7

!Grid type (here, regular grid)
 pshead%mesh_type=1

!Maximum value for l quantum number
 pshead%lmax=maxval(pshead%orbitals(1:pshead%basis_size))
 pshead%l_size=2*pshead%lmax+1
 pshead%lmn2_size=pshead%lmn_size*(pshead%lmn_size+1)/2

!Sizes of radial meshes
 pshead%vloc_meshsz=max(pshead%sph_meshsz,max(pshead%core_meshsz,int(1.d0+rmax_vloc/pshead%rad_step)))
 pawdata%max_meshsz=max(pshead%sph_meshsz,pshead%core_meshsz,pshead%vloc_meshsz)

!Initialization of the orbital basis indexes (indlmn)
 ilmn=0;iln=0
 do il=0,pshead%lmax
  nproj=0
  do ib=1,pshead%basis_size
   if (pshead%orbitals(ib)==il) then
    nproj=nproj+1;iln=iln+1
    do ilm=1,2*il+1
     pawdata%indlmn(1,ilmn+ilm)=il
     pawdata%indlmn(2,ilmn+ilm)=ilm-(il+1)
     pawdata%indlmn(3,ilmn+ilm)=nproj
     pawdata%indlmn(4,ilmn+ilm)=il*il+ilm
     pawdata%indlmn(5,ilmn+ilm)=iln
     pawdata%indlmn(6,ilmn+ilm)=1
    enddo
    ilmn=ilmn+2*il+1
   endif
  enddo
 enddo

!Translation of the exchange-correlation type
!   --LDA calculation with the PW 92 functional
 if(pshead%pspxc_atom==14) then
  pshead%pspxc_abinit=7
!   --GGA calculation with the PBE functional
 elseif (pshead%pspxc_atom==16) then
  pshead%pspxc_abinit=11
 else
  write(6,*) 'Big Pb: exchange and correlation'
  write(6,*) '        fonctionnal does not exist !'
  stop
 endif

 end subroutine
!!***
